@@ -2,7 +2,7 @@
 #'
 #' Sets up an Interrupted Time Series Analysis (ITSA) for analysing short time series data.
 #'
-#' @param data define data.
+#' @param data define data. Must be a data frame or object coercible into a data frame.
 #' @param time define time variable, must either be numeric (such as a year) or of class date.
 #' @param depvar define dependent variable, must be continuous.
 #' @param interrupt_var define interruption treatment/condition variable, must be a factor.
@@ -10,7 +10,8 @@
 #' @param alpha desired alpha (p-value boundary of null hypothesis rejection), default is 0.05.
 #' @param no.plots logical, specify that function should not return the ITSA plot, default is FALSE.
 #' @param bootstrap logical, specify where function should run bootstrap estimations of F-values and return table of results, default is TRUE.
-#' @param Reps define number of replications for bootstrapping, default is 1000.
+#' @param Reps numeric, define number of replications for bootstrapping, default is 1000.
+#' @param parr character, define if parallelisation should be used for bootstrapper, options are inherited from boot package (the default of "no", or "multicore" and "snow").
 #' @param print logical, specify whether the main model result should be printed to the console.
 #' @return Returns a large list which can be assigned to the global environment, containing results and necessary information for running post-estimation itsa.postest function. It also contains the Time Series Interruption plot (itsa.plot) and bootstrap results, if applied.
 #' @export itsa.model
@@ -20,12 +21,12 @@
 #' # Build variables
 #'
 #' year <- c(2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-#' 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016)
+#' 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018)
 #' depv <- c(8.22, 8.19, 8.23, 8.28, 8.32, 8.39, 8.02,
-#' 7.92, 7.62, 7.23, 7.1, 6.95, 7.36, 7.51, 7.78, 7.92)
-#' interruption <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0)
+#' 7.92, 7.62, 7.23, 7.1, 7.11, 6.95, 7.36, 7.51, 7.78, 7.92, 7.81)
+#' interruption <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0)
 #' cov1 <- c(3.1, 3.3, 5.1, 5.2, 5.4, 4.5, 4.7, 4.9, 5.3,
-#' 5.6, 5.8, 4.8, 5.2, 4.5, 4.6, 5.1)
+#' 5.6, 5.8, 6.0, 4.8, 5.2, 4.5, 4.6, 5.1, 4.7)
 #'
 #' x <- as.data.frame(cbind(year, depv, interruption, cov1))
 #'
@@ -46,11 +47,11 @@
 #'  alpha=0.05, bootstrap=FALSE)
 #'
 #'
-#' @details This function provides an Interrupted Time Series Analysis (ITSA) model using a variance-centric approach to estimating change over time.
+#' @details This function provides an Interrupted Time Series Analysis (ITSA) model using a variance-centric approach to estimating change in a dependent variable over time.
 #'
-#' Using the inputted variables, a Type-2 Sum Squares ANCOVA Lagged Dependent Variable model is fitted which estimates the difference in means between interrupted and non-interrupted time periods, while accounting for the lag of the dependent variable and any further specified covariates.
+#' Using the defined variables, a Type-2 Sum Squares ANCOVA Lagged Dependent Variable model is fitted which estimates the difference in means between interrupted and non-interrupted time periods, while accounting for the lag of the dependent variable and any further specified covariates.
 #'
-#' The function includes a bootstrap model by default, which runs 1000 replications of the main model with randomly drawn samples. A trimmed mean (10 percent removed) F-value is reported and a bootstrapped p-value derived from it. Users may turn off the bootstrapping model, or the number of replications for the bootstrap model to pass through can be altered using the Reps argument.
+#' The function includes a bootstrap model, which runs by default. This repeats 1000 replications of the main model with randomly drawn samples. A trimmed median (10 percent removed) F-value is reported and a bootstrapped p-value derived from it. Users may turn off the bootstrapping model, or the number of replications for the bootstrap model to pass through can be altered using the Reps argument.
 #'
 #' Variable names must be defined using quotation marks, or their column index number within the data. Any number of covariates can be passed into the covariates argument as a list of vectors (both must be within the same data as the dependent and independent variables).
 #'
@@ -58,7 +59,7 @@
 #'
 #' Returns to console the results from analysis of variance test, results of the F-value bootstrap model, and a summary of the result (relative to user defined alpha) and any assumption violation warnings. Users may force this return off by declaring print=FALSE in the model arguments.
 #'
-#' Also returns a plot to the plot window graphing the dependent variable time series and interruption points. As this is a ggplot2 generated object, users can call the plot and make further customisations to it as an output.
+#' Further returns a plot to the plot window graphing the dependent variable time series and interruption points. As this is a ggplot2 generated object, users can call the plot and make further customisations to it as an output.
 #'
 #' Assigning to an object will return a list of all of the above, plus further tests including a Tukey Honest Significant Differences test, the data and arguments set by the user, a table of time-series group means, the full bootstrap model results and results of assumptions tests, and the full list of residual and fitted values.
 #'
@@ -66,7 +67,8 @@
 
 
 itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var = NULL,
-                       covariates = NULL, alpha = 0.05, no.plots=FALSE, bootstrap=TRUE, Reps=1000, print=TRUE) {
+                       covariates = NULL, alpha = 0.05, no.plots=FALSE,
+                       bootstrap=TRUE, Reps=1000, parr="no", print=TRUE) {
 
   ## Save global options and set new ones
   user.ops <- options()
@@ -75,10 +77,6 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
 
   on.exit(options(user.ops))
 
-  #par.user <- graphics::par(no.readonly = TRUE)
-
-  #on.exit(graphics::par(par.user), add=TRUE)
-
 
 
   ## Check variable specifications
@@ -118,6 +116,10 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
   }
 
 
+  ## Coerce data to data frame
+  x <- as.data.frame(x)
+
+
   ## Build object for means (point-estimates)
 
   ITSMeanValues <- plyr::ddply(x, ~interrupt_var,
@@ -158,7 +160,7 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
   }
 
   else {
-   itsa.plot <- "No plot forced"
+   itsa.plot <- "No plot specified"
   }
 
 
@@ -197,20 +199,21 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
 
     f.stat <- function(formula, data, indices) {
       d <- data[indices,]
-      fit <- car::Anova(stats::aov(formula, data=d))
+      mod <- stats::aov(formula, data=d)
+      fit <- car::Anova(mod, type=2)
       return(fit$`F value`)
     }
 
-    f.stat.boot.results <- boot::boot(data=x, statistic=f.stat, R=Reps, formula=depvar ~ .)
+    f.stat.boot.results <- boot::boot(data=x, statistic=f.stat, R=Reps, formula=depvar ~ ., parallel = parr)
 
 
     booted.ints <- matrix(nrow=(ncol(f.stat.boot.results$t)-1), ncol=4)
 
     for(i in 1:(ncol(f.stat.boot.results$t)-1)){
 
-      boots <- boot::boot.ci(f.stat.boot.results, type="perc", index=i)
+      boots <- boot::boot.ci(f.stat.boot.results, conf = 0.9, type="perc", index=i)
       booted.ints[i,2] <- boots$percent[,4]
-      booted.ints[i,3] <- mean(f.stat.boot.results$t[,i], na.rm=TRUE, trim = 0.1)
+      booted.ints[i,3] <- stats::median(f.stat.boot.results$t[,i], na.rm=TRUE, trim = 0.1)
       booted.ints[i,4] <- boots$percent[,5]
 
     }
@@ -219,13 +222,7 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
     names <- colnames(x)
     names <- names[2:length(names)]
     booted.ints$V1 <- names
-    names(booted.ints) <- c("Parameter", "Lower CI", "Mean F-value", "Upper CI")
-
-    booted.ints$`P-value` <- NA
-
-    for(i in 1:nrow(booted.ints)){
-      booted.ints[i,5] <- stats::pf(booted.ints[i,3], df1= ITSModResult[i,2], df2=ITSModResult["Residuals",2], lower.tail = FALSE)
-    }
+    names(booted.ints) <- c("Parameter", "Lower CI", "Median F-value", "Upper CI")
 
 
   }
@@ -304,7 +301,7 @@ itsa.model <- function(data = NULL, time = NULL, depvar = NULL, interrupt_var =
 
       if(bootstrap==TRUE){
         cat(paste('Bootstrapped F-values:', '\n'))
-        print(itsa.fit$booted.ints[1,c(2:5)], digits=5, row.names=FALSE)
+        print(itsa.fit$booted.ints[1,c(2:4)], digits=5, row.names=FALSE)
 
       }
 
